ktch
============================================

ktch is a python package for model-based morphometrics.


.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Documentation

   user_guide/index
   api/index

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Tutorial - Examples

   notebooks/index


`User Guide <user_guide/index.html>`_
-------------------------------------------------

User Guide is an overview and explains the key concepts and the important features.

`API <api/index.html>`_
-------------------------------------------------

API documentation details classes, functions, modules, and other objects included in ktch.

`Example notebooks <notebooks/index.html>`_
-------------------------------------------------

A set of example notebooks. It complements the `User Guide <user_guide/index.html>`_.